@@ -2,14 +2,13 @@
 # -*- coding: utf-8 -*-
 # @Author : EXP
 # @Time   : 2020/4/29 22:14
-# @File   : _sqlite.py
 # -----------------------------------------------
 # Sqlite 数据库连接器
 # -----------------------------------------------
 
 import sqlite3
+from color_log.clog import log
 from ..assist.cfg import *
-from ..assist import log
 
 
 class SqliteDBC :
